@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.utils import simplejson
 from django.core.urlresolvers import reverse
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.test.utils import override_settings
 from django.core.signing import get_cookie_signer
 
@@ -9,6 +9,8 @@ from leaflet_storage.models import Map, DataLayer
 
 from .base import (MapFactory, UserFactory, BaseTest)
 
+User = get_user_model()
+
 
 @override_settings(LEAFLET_STORAGE_ALLOW_ANONYMOUS=False)
 class MapViews(BaseTest):
